@@ -7,10 +7,11 @@
 #' @return A ggplot theme.
 #' @export
 #' @examples
+#' library(ggplot2)
 #' 
-#' ggplot2::ggplot() +
+#' ggplot() +
 #'   theme_box("Courier", 9, 7) +
-#'   ggplot2::ggtitle("This is a title of a selected font family and size")
+#'   ggtitle("This is a title of a selected font family and size")
 theme_box <-
   function(font_family = "Helvetica",
            font_size_title = 11,
@@ -118,11 +119,14 @@ theme_box <-
 #' @param stat String of "boxplot" or "identity". Defaults to "boxplot". If identity is selected, data provided must be grouped by the x_var with ymin, lower, middle, upper, ymax variables. Note "identity" does not provide outliers.
 #' @param x_labels Argument to adjust the format of the x scale labels.
 #' @param x_pretty_n The desired number of intervals on the x axis, as calculated by the pretty algorithm. Defaults to 6. Only applicable to a x variable that is categorical or date.
+#' @param x_expand A vector of range expansion constants used to add some padding on the x scale. 
 #' @param y_zero TRUE or FALSE of whether the minimum of the y scale is zero. Defaults to TRUE.
-#' @param y_zero_line TRUE or FALSE whether to add a zero line in for when values are above and below zero. Defaults to TRUE.  
+#' @param y_zero_line TRUE or FALSE whether to add a zero reference line to the y axis. Defaults to NULL, which is TRUE if there are positive and negative values in y_var. Otherwise it is FALSE.  
 #' @param y_trans TRUEransformation of y-axis scale (e.g. "signed_sqrt"). Defaults to "identity", which has no transformation.
 #' @param y_labels Argument to adjust the format of the y scale labels.
 #' @param y_pretty_n The desired number of intervals on the y axis, as calculated by the pretty algorithm. Defaults to 5. 
+#' @param y_expand A vector of range expansion constants used to add some padding on the y scale. 
+#' @param y_balance Add balance to the y axis so that zero is in the centre of the y scale.
 #' @param pal Character vector of hex codes. Defaults to NULL, which selects the Stats NZ palette.
 #' @param width Width of the box. Defaults to 0.5.
 #' @param title Title string. Defaults to "[Title]".
@@ -133,11 +137,11 @@ theme_box <-
 #' @param font_family Font family to use. Defaults to "Helvetica".
 #' @param font_size_title Font size for the title text. Defaults to 11.
 #' @param font_size_body Font size for all text other than the title. Defaults to 10.
-#' @param wrap_title Number of characters to wrap the title to. Defaults to 70. Not applicable where isMobile equals TRUE.
-#' @param wrap_subtitle Number of characters to wrap the subtitle to. Defaults to 80. Not applicable where isMobile equals TRUE.
-#' @param wrap_x_title Number of characters to wrap the x title to. Defaults to 50. Not applicable where isMobile equals TRUE.
-#' @param wrap_y_title Number of characters to wrap the y title to. Defaults to 50. Not applicable where isMobile equals TRUE.
-#' @param wrap_caption Number of characters to wrap the caption to. Defaults to 80. Not applicable where isMobile equals TRUE.
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. Not applicable where isMobile equals TRUE.
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. Not applicable where isMobile equals TRUE.
+#' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. Not applicable where isMobile equals TRUE.
+#' @param y_title_wrap Number of characters to wrap the y title to. Defaults to 50. Not applicable where isMobile equals TRUE.
+#' @param caption_wrap Number of characters to wrap the caption to. Defaults to 80. Not applicable where isMobile equals TRUE.
 #' @param isMobile Whether the plot is to be displayed on a mobile device. Defaults to FALSE. If within an app with the mobileDetect function, then use isMobile = input$isMobile.
 #' @return A ggplot object.
 #' @export
@@ -148,14 +152,10 @@ theme_box <-
 #' tibble::as_tibble() %>%
 #'   mutate(Species = stringr::str_to_sentence(Species))
 #'
-#' plot <- ggplot_box(data = plot_data, x_var = Species, y_var = Petal.Length,
-#'                     title = "Iris petal length by species",
-#'                     x_title = "Species",
-#'                     y_title = "Petal length (cm)")
-#'
-#' plot
-#'
-#' plotly::ggplotly(plot)
+#' ggplot_box(plot_data, Species, Petal.Length,
+#'   title = "Iris petal length by species",
+#'   x_title = "Species",
+#'   y_title = "Petal length (cm)")
 #'
 #' plot_data <- iris %>%
 #'   group_by(Species) %>%
@@ -163,7 +163,8 @@ theme_box <-
 #'   c('ymin','lower','middle','upper','ymax')))) %>%
 #'   tidyr::unnest_wider(boxplot_stats)
 #'
-#' ggplot_box(data = plot_data, x_var = Species, y_var = Petal.Length, stat = "identity")
+#' ggplot_box(plot_data, Species, Petal.Length, stat = "identity")
+#' 
 ggplot_box <- function(data,
                        x_var,
                        y_var = NULL,
@@ -171,11 +172,14 @@ ggplot_box <- function(data,
                        stat = "boxplot",
                        x_labels = waiver(),
                        x_pretty_n = 6,
+                       x_expand = NULL,
                        y_zero = TRUE,
-                       y_zero_line = TRUE,
+                       y_zero_line = NULL,
                        y_trans = "identity",
                        y_labels = waiver(),
                        y_pretty_n = 5,
+                       y_expand = NULL,
+                       y_balance = FALSE,
                        pal = NULL,
                        width = 0.5,
                        title = "[Title]",
@@ -186,11 +190,11 @@ ggplot_box <- function(data,
                        font_family = "Helvetica",
                        font_size_title = NULL,
                        font_size_body = NULL,
-                       wrap_title = 70,
-                       wrap_subtitle = 80,
-                       wrap_x_title = 50,
-                       wrap_y_title = 50,
-                       wrap_caption = 80,
+                       title_wrap = 70,
+                       subtitle_wrap = 80,
+                       x_title_wrap = 50,
+                       y_title_wrap = 50,
+                       caption_wrap = 80,
                        isMobile = FALSE) {
   
   data <- dplyr::ungroup(data)
@@ -198,16 +202,22 @@ ggplot_box <- function(data,
   y_var <- rlang::enquo(y_var) #numeric var
   group_var <- rlang::enquo(group_var)
   
-  x_var_vector <- dplyr::pull(data, !!x_var)
-  if (stat == "boxplot") y_var_vector <- dplyr::pull(data, !!y_var)
-  else if (stat == "identity") y_var_vector <- c(dplyr::pull(data, .data$ymin), dplyr::pull(data, .data$ymax))
+  x_var_vctr <- dplyr::pull(data, !!x_var)
+  if (stat == "boxplot") y_var_vctr <- dplyr::pull(data, !!y_var)
+  else if (stat == "identity") y_var_vctr <- c(dplyr::pull(data, .data$ymin), dplyr::pull(data, .data$ymax))
 
-  if (!is.numeric(y_var_vector)) stop("Please use a numeric y variable for a boxplot")
+  if (!is.numeric(y_var_vctr)) stop("Please use a numeric y variable for a boxplot")
 
-  min_y_var_vector <- min(y_var_vector, na.rm = TRUE)
-  max_y_var_vector <- max(y_var_vector, na.rm = TRUE)
-  if(min_y_var_vector < 0 & max_y_var_vector > 0 & y_zero == TRUE) {
-    y_zero <- FALSE
+  min_y_var_vctr <- min(y_var_vctr, na.rm = TRUE)
+  max_y_var_vctr <- max(y_var_vctr, na.rm = TRUE)
+  
+  y_above_and_below_zero <- ifelse(min_y_var_vctr < 0 & max_y_var_vctr > 0, TRUE, FALSE)
+  
+  if(y_above_and_below_zero == TRUE) y_zero <- FALSE
+  
+  if(is.null(y_zero_line)) {
+    if(y_above_and_below_zero == TRUE | y_balance == TRUE) y_zero_line <- TRUE
+    else(y_zero_line <- FALSE)
   }
   
   if(is.null(font_size_title)){
@@ -268,63 +278,87 @@ ggplot_box <- function(data,
         alpha = 0.9
       )
   }
+
+  if(is.null(x_expand)) x_expand <- waiver()
+  if(is.null(y_expand)) y_expand <- c(0, 0)
   
-  if (lubridate::is.Date(x_var_vector)) {
+  if (lubridate::is.Date(x_var_vctr)) {
     if(isMobile == FALSE) x_n <- x_pretty_n
     else if(isMobile == TRUE) x_n <- 4
     
-    x_breaks <- pretty(x_var_vector, n = x_n)
+    x_breaks <- pretty(x_var_vctr, n = x_n)
     
     plot <- plot +
       scale_x_date(
-        expand = c(0, 0),
+        expand = x_expand,
         breaks = x_breaks,
         labels = x_labels
       )
   }
-  else if (is.numeric(x_var_vector)) {
+  else if (is.numeric(x_var_vctr)) {
     if(isMobile == FALSE) x_n <- x_pretty_n
     else if(isMobile == TRUE) x_n <- 4
     
-    x_breaks <- pretty(x_var_vector, n = x_n)
+    x_breaks <- pretty(x_var_vctr, n = x_n)
     
     plot <- plot +
-      scale_x_continuous(expand = c(0, 0),
+      scale_x_continuous(expand = x_expand,
                          breaks = x_breaks,
                          labels = x_labels,
                          oob = scales::rescale_none)
   }
-  else if (is.character(x_var_vector) | is.factor(x_var_vector)){
-    plot <- plot +
-      scale_x_discrete(labels = x_labels)
+  else if (is.character(x_var_vctr) | is.factor(x_var_vctr)){
+    if (isMobile == FALSE){
+      if(is.null(y_labels)) y_labels <- waiver()
+      
+      plot <- plot +
+        scale_x_discrete(expand = x_expand, labels = x_labels)
+    }
+    else if (isMobile == TRUE){
+      if(is.character(x_labels)) {
+        plot <- plot +
+          scale_x_discrete(expand = x_expand, labels = stringr::str_wrap(x_labels, 20))
+      }
+      else {
+        plot <- plot +
+          scale_x_discrete(expand = x_expand, labels = function(x) stringr::str_wrap(x, 20))
+      }
+    }
   }
   
-  if (all(y_var_vector == 0, na.rm = TRUE)) {
-    y_limits <- c(0, 1)
-    
+  if (all(y_var_vctr == 0, na.rm = TRUE)) {
     plot <- plot +
-      ggplot2::scale_y_continuous(breaks = c(0, 1), labels = y_labels, limits = y_limits)
+      scale_y_continuous(breaks = c(0, 1), labels = y_labels, limits = c(0, 1))
   }
   else ({
+    if (y_balance == TRUE) {
+      y_var_vctr <- abs(y_var_vctr)
+      y_var_vctr <- c(-y_var_vctr, y_var_vctr)
+    }
     if (y_zero == TRUE) {
-      if(max_y_var_vector > 0) y_breaks <- pretty(c(0, y_var_vector), n = y_pretty_n)
-      if(min_y_var_vector < 0) y_breaks <- pretty(c(y_var_vector, 0), n = y_pretty_n)
+      if(max_y_var_vctr > 0) y_breaks <- pretty(c(0, y_var_vctr), n = y_pretty_n)
+      if(min_y_var_vctr < 0) y_breaks <- pretty(c(y_var_vctr, 0), n = y_pretty_n)
       
       if(y_trans == "log10") y_breaks <- c(1, y_breaks[y_breaks > 1])
       y_limits <- c(min(y_breaks), max(y_breaks))
     }
     else if (y_zero == FALSE) {
-      if(y_trans != "log10") y_breaks <- pretty(y_var_vector, n = y_pretty_n)
+      if(y_trans != "log10") y_breaks <- pretty(y_var_vctr, n = y_pretty_n)
       if(y_trans == "log10") {
-        y_breaks <- pretty(c(0, y_var_vector), n = y_pretty_n) 
+        y_breaks <- pretty(c(0, y_var_vctr), n = y_pretty_n) 
         y_breaks <- c(1, y_breaks[y_breaks > 1])
       }
       y_limits <- c(min(y_breaks), max(y_breaks))
     }
-  
+    
+    if(isMobile == TRUE) {
+      y_breaks <- y_limits
+      if (min(y_limits) < 0 & max(y_limits > 0)) y_breaks <- c(y_limits[1], 0, y_limits[2])
+    }
+
     plot <- plot +
       scale_y_continuous(
-        expand = c(0, 0),
+        expand = y_expand,
         breaks = y_breaks,
         limits = y_limits,
         trans = y_trans,
@@ -333,23 +367,25 @@ ggplot_box <- function(data,
       )
   })
 
-  if(min_y_var_vector < 0 & max_y_var_vector > 0 & y_zero_line == TRUE) {
+  if(y_zero_line == TRUE) {
     plot <- plot +
-      ggplot2::geom_hline(yintercept = 0, colour = "#323232", size = 0.3)
+      geom_hline(yintercept = 0, colour = "#323232", size = 0.3)
   }
 
   if (isMobile == FALSE){
     plot <- plot +
       labs(
-        title = stringr::str_wrap(title, wrap_title),
-        subtitle = stringr::str_wrap(subtitle, wrap_subtitle),
-        x = stringr::str_wrap(x_title, wrap_x_title),
-        y = stringr::str_wrap(y_title, wrap_y_title),
-        caption = stringr::str_wrap(caption, wrap_caption)
+        title = stringr::str_wrap(title, title_wrap),
+        subtitle = stringr::str_wrap(subtitle, subtitle_wrap),
+        x = stringr::str_wrap(x_title, x_title_wrap),
+        y = stringr::str_wrap(y_title, y_title_wrap),
+        caption = stringr::str_wrap(caption, caption_wrap)
       ) 
   }
   else if (isMobile == TRUE){
     plot <- plot +
+      theme(plot.title.position = "plot") +
+      theme(plot.caption.position = "plot") +
       labs(
         title = stringr::str_wrap(title, 40),
         subtitle = stringr::str_wrap(subtitle, 40),
@@ -359,7 +395,8 @@ ggplot_box <- function(data,
       ) +
       coord_flip() +
       theme(panel.grid.major.x = element_line(colour = "#D3D3D3", size = 0.2)) +
-      theme(panel.grid.major.y = element_blank())
+      theme(panel.grid.major.y = element_blank()) +
+      theme(axis.text.x = element_text(hjust = 1))  
   }
   
   return(plot)
@@ -375,13 +412,16 @@ ggplot_box <- function(data,
 #' @param stat String of "boxplot" or "identity". Defaults to "boxplot". If identity is selected, data provided must be grouped by the x_var and facet_var with ymin, lower, middle, upper, ymax variables. Note "identity" does not provide outliers.
 #' @param x_labels Argument to adjust the format of the x scale labels.
 #' @param x_pretty_n The desired number of intervals on the x axis, as calculated by the pretty algorithm. Defaults to 5. Only applicable to a x variable that is categorical or date.
+#' @param x_expand A vector of range expansion constants used to add some padding on the x scale. 
 #' @param y_zero TRUE or FALSE of whether the minimum of the y scale is zero. Defaults to TRUE.
-#' @param y_zero_line TRUE or FALSE whether to add a zero line in for when values are above and below zero. Defaults to TRUE.  
+#' @param y_zero_line TRUE or FALSE whether to add a zero reference line to the y axis. Defaults to NULL, which is TRUE if there are positive and negative values in y_var. Otherwise it is FALSE.  
 #' @param y_trans TRUEransformation of y-axis scale (e.g. "signed_sqrt"). Defaults to "identity", which has no transformation.
 #' @param y_labels Argument to adjust the format of the y scale labels.
 #' @param y_pretty_n The desired number of intervals on the y axis, as calculated by the pretty algorithm. Defaults to 5. 
+#' @param y_expand A vector of range expansion constants used to add some padding on the y scale. 
+#' @param y_balance Add balance to the y axis so that zero is in the centre of the y scale. Only applicable where facet_scales equals "fixed" or "free_x".
 #' @param facet_scales Whether facet_scales should be "fixed" across facets, "free" in both directions, or free in just one direction (i.e. "free_x" or "free_y"). Defaults to "fixed".
-#' @param facet_nrow The number of rows of facetted plots. Defaults to NULL, which generally chooses 2 rows. Not applicable to where isMobile is TRUE.
+#' @param facet_nrow The number of rows of facetted plots. Defaults to NULL, which generally chooses 2 rows. 
 #' @param pal Character vector of hex codes. Defaults to NULL, which selects the Stats NZ palette.
 #' @param width Width of the box. Defaults to 0.5.
 #' @param title Title string. Defaults to "[Title]".
@@ -392,12 +432,11 @@ ggplot_box <- function(data,
 #' @param font_family Font family to use. Defaults to "Helvetica".
 #' @param font_size_title Font size for the title text. Defaults to 11.
 #' @param font_size_body Font size for all text other than the title. Defaults to 10.
-#' @param wrap_title Number of characters to wrap the title to. Defaults to 70. Not applicable where isMobile equals TRUE.
-#' @param wrap_subtitle Number of characters to wrap the subtitle to. Defaults to 80. Not applicable where isMobile equals TRUE.
-#' @param wrap_x_title Number of characters to wrap the x title to. Defaults to 50. Not applicable where isMobile equals TRUE.
-#' @param wrap_y_title Number of characters to wrap the y title to. Defaults to 50. Not applicable where isMobile equals TRUE.
-#' @param wrap_caption Number of characters to wrap the caption to. Defaults to 80. Not applicable where isMobile equals TRUE.
-#' @param isMobile Whether the plot is to be displayed on a mobile device. Defaults to FALSE. If within an app with the mobileDetect function, then use isMobile = input$isMobile.
+#' @param title_wrap Number of characters to wrap the title to. Defaults to 70. 
+#' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
+#' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
+#' @param y_title_wrap Number of characters to wrap the y title to. Defaults to 50. 
+#' @param caption_wrap Number of characters to wrap the caption to. Defaults to 80. 
 #' @return A ggplot object.
 #' @export
 #' @examples
@@ -407,12 +446,8 @@ ggplot_box <- function(data,
 #'   mutate(price_thousands = (price / 1000)) %>%
 #'   slice_sample(prop = 0.05)
 #'
-#' plot <- ggplot_box_facet(data = plot_data, x_var = cut, y_var = price_thousands, facet_var = color,
-#'                          facet_nrow = 4)
+#' ggplot_box_facet(plot_data, cut, price_thousands, color)
 #'
-#' plot
-#'
-#' plotly::ggplotly(plot)
 ggplot_box_facet <-
   function(data,
            x_var,
@@ -422,11 +457,14 @@ ggplot_box_facet <-
            stat = "boxplot",
            x_labels = waiver(),
            x_pretty_n = 5,
+           x_expand = NULL,
            y_zero = TRUE,
-           y_zero_line = TRUE,
+           y_zero_line = NULL,
            y_trans = "identity",
            y_labels = waiver(),
            y_pretty_n = 5,
+           y_expand = NULL,
+           y_balance = FALSE,
            facet_scales = "fixed",
            facet_nrow = NULL,
            pal = NULL,
@@ -439,12 +477,11 @@ ggplot_box_facet <-
            font_family = "Helvetica",
            font_size_title = NULL,
            font_size_body = NULL,
-           wrap_title = 70,
-           wrap_subtitle = 80,
-           wrap_x_title = 50,
-           wrap_y_title = 50,
-           wrap_caption = 80,
-           isMobile = FALSE) {
+           title_wrap = 70,
+           subtitle_wrap = 80,
+           x_title_wrap = 50,
+           y_title_wrap = 50,
+           caption_wrap = 80) {
     
     data <- dplyr::ungroup(data)
     x_var <- rlang::enquo(x_var) 
@@ -452,29 +489,29 @@ ggplot_box_facet <-
     facet_var <- rlang::enquo(facet_var) #categorical var
     group_var <- rlang::enquo(group_var) 
     
-    x_var_vector <- dplyr::pull(data, !!x_var) 
-    if (stat == "boxplot") y_var_vector <- dplyr::pull(data, !!y_var)
-    else if (stat == "identity") y_var_vector <- c(dplyr::pull(data, .data$ymin), dplyr::pull(data, .data$ymax))
-    facet_var_vector <- dplyr::pull(data, !!facet_var)
+    x_var_vctr <- dplyr::pull(data, !!x_var) 
+    if (stat == "boxplot") y_var_vctr <- dplyr::pull(data, !!y_var)
+    else if (stat == "identity") y_var_vctr <- c(dplyr::pull(data, .data$ymin), dplyr::pull(data, .data$ymax))
+    facet_var_vctr <- dplyr::pull(data, !!facet_var)
     
-    if (!is.numeric(y_var_vector)) stop("Please use a numeric y variable for a boxplot")
-    if (is.numeric(facet_var_vector)) stop("Please use a categorical facet variable for a boxplot")
+    if (!is.numeric(y_var_vctr)) stop("Please use a numeric y variable for a boxplot")
+    if (is.numeric(facet_var_vctr)) stop("Please use a categorical facet variable for a boxplot")
     
-    min_y_var_vector <- min(y_var_vector, na.rm = TRUE)
-    max_y_var_vector <- max(y_var_vector, na.rm = TRUE)
-    if(min_y_var_vector < 0 & max_y_var_vector > 0 & y_zero == TRUE) {
-      y_zero <- FALSE
-    }
+    min_y_var_vctr <- min(y_var_vctr, na.rm = TRUE)
+    max_y_var_vctr <- max(y_var_vctr, na.rm = TRUE)
     
-    if(is.null(font_size_title)){
-      if (isMobile == FALSE) font_size_title <- 11
-      else if (isMobile == TRUE) font_size_title <- 15
-    }
-    if(is.null(font_size_body)){
-      if (isMobile == FALSE) font_size_body <- 10
-      else if (isMobile == TRUE) font_size_body <- 14
+    y_above_and_below_zero <- ifelse(min_y_var_vctr < 0 & max_y_var_vctr > 0, TRUE, FALSE)
+    
+    if(y_above_and_below_zero == TRUE) y_zero <- FALSE
+    
+    if(is.null(y_zero_line)) {
+      if(y_above_and_below_zero == TRUE | y_balance == TRUE) y_zero_line <- TRUE
+      else(y_zero_line <- FALSE)
     }
     
+    if(is.null(font_size_title)) font_size_title <- 11
+    if(is.null(font_size_body)) font_size_body <- 10
+
     if (is.null(pal)) pal <- pal_snz
     
     plot <- ggplot(data) +
@@ -509,74 +546,77 @@ ggplot_box_facet <-
     }
     else if (stat == "identity") {
       plot <- ggplot(data) +
-      coord_cartesian(clip = "off") +
-      theme_box(
-        font_family = font_family,
-        font_size_body = font_size_body,
-        font_size_title = font_size_title
-      ) +
-      geom_boxplot(
-        aes(
-          x = !!x_var,
-          ymin = .data$ymin,
-          lower = .data$lower,
-          middle = .data$middle,
-          upper = .data$upper,
-          ymax = .data$ymax
-        ),
-        stat = stat,
-        fill = pal[1],
-        width = width,
-        alpha = 0.9
-      )
+        coord_cartesian(clip = "off") +
+        theme_box(
+          font_family = font_family,
+          font_size_body = font_size_body,
+          font_size_title = font_size_title
+        ) +
+        geom_boxplot(
+          aes(
+            x = !!x_var,
+            ymin = .data$ymin,
+            lower = .data$lower,
+            middle = .data$middle,
+            upper = .data$upper,
+            ymax = .data$ymax
+          ),
+          stat = stat,
+          fill = pal[1],
+          width = width,
+          alpha = 0.9
+        )
     }
     
+    if(is.null(x_expand)) x_expand <- waiver()
+    if(is.null(y_expand)) y_expand <- c(0, 0)
+    
     if (facet_scales %in% c("fixed", "free_y")) {
       
-      if (lubridate::is.Date(x_var_vector)) {
-        if(isMobile == FALSE) x_n <- x_pretty_n
-        else if(isMobile == TRUE) x_n <- 4
-        
-        x_breaks <- pretty(x_var_vector, n = x_n)
+      if (lubridate::is.Date(x_var_vctr)) {
+        x_n <- x_pretty_n
+        x_breaks <- pretty(x_var_vctr, n = x_n)
         
         plot <- plot +
           scale_x_date(
-            expand = c(0, 0),
+            expand = x_expand,
             breaks = x_breaks,
             labels = x_labels
           )
       }
-      else if (is.numeric(x_var_vector)) {
-        if(isMobile == FALSE) x_n <- x_pretty_n
-        else if(isMobile == TRUE) x_n <- 4
-        
-        x_breaks <- pretty(x_var_vector, n = x_n)
+      else if (is.numeric(x_var_vctr)) {
+        x_n <- x_pretty_n
+        x_breaks <- pretty(x_var_vctr, n = x_n)
         
         plot <- plot +
-          scale_x_continuous(expand = c(0, 0),
+          scale_x_continuous(expand = x_expand,
                              breaks = x_breaks,
                              labels = x_labels,
                              oob = scales::rescale_none)
       }
-      else if (is.character(x_var_vector) | is.factor(x_var_vector)){
+      else if (is.character(x_var_vctr) | is.factor(x_var_vctr)){
         plot <- plot +
-          scale_x_discrete(labels = x_labels)
+          scale_x_discrete(expand = x_expand, labels = x_labels)
       }
       
     }
-
+    
     if (facet_scales %in% c("fixed", "free_x")) {
+      if (y_balance == TRUE) {
+        y_var_vctr <- abs(y_var_vctr)
+        y_var_vctr <- c(-y_var_vctr, y_var_vctr)
+      }
       if (y_zero == TRUE) {
-        if(max_y_var_vector > 0) y_breaks <- pretty(c(0, y_var_vector), n = y_pretty_n)
-        if(min_y_var_vector < 0) y_breaks <- pretty(c(y_var_vector, 0), n = y_pretty_n)
+        if(max_y_var_vctr > 0) y_breaks <- pretty(c(0, y_var_vctr), n = y_pretty_n)
+        if(min_y_var_vctr < 0) y_breaks <- pretty(c(y_var_vctr, 0), n = y_pretty_n)
         
         if(y_trans == "log10") y_breaks <- c(1, y_breaks[y_breaks > 1])
         y_limits <- c(min(y_breaks), max(y_breaks))
       }
       else if (y_zero == FALSE) {
-        if(y_trans != "log10") y_breaks <- pretty(y_var_vector, n = y_pretty_n)
+        if(y_trans != "log10") y_breaks <- pretty(y_var_vctr, n = y_pretty_n)
         if(y_trans == "log10") {
-          y_breaks <- pretty(c(0, y_var_vector), n = y_pretty_n) 
+          y_breaks <- pretty(c(0, y_var_vctr), n = y_pretty_n) 
           y_breaks <- c(1, y_breaks[y_breaks > 1])
         }
         y_limits <- c(min(y_breaks), max(y_breaks))
@@ -584,7 +624,7 @@ ggplot_box_facet <-
       
       plot <- plot +
         scale_y_continuous(
-          expand = c(0, 0),
+          expand = y_expand,
           breaks = y_breaks,
           limits = y_limits,
           trans = y_trans,
@@ -594,45 +634,29 @@ ggplot_box_facet <-
     }
     else if (facet_scales %in% c("free", "free_y")) {
       plot <- plot +
-        scale_y_continuous(expand = c(0, 0),
+        scale_y_continuous(expand = y_expand,
                            trans = y_trans,
                            labels = y_labels,
                            oob = scales::rescale_none)
     }    
     
-    if(min_y_var_vector < 0 & max_y_var_vector > 0 & y_zero_line == TRUE) {
+    if(y_zero_line == TRUE) {
       plot <- plot +
-        ggplot2::geom_hline(yintercept = 0, colour = "#323232", size = 0.3)
+        geom_hline(yintercept = 0, colour = "#323232", size = 0.3)
     }
     
-    if (isMobile == FALSE){
-      if (is.null(facet_nrow) & length(unique(facet_var_vector)) <= 3) facet_nrow <- 1
-      if (is.null(facet_nrow) & length(unique(facet_var_vector)) > 3) facet_nrow <- 2
-      
-      plot <- plot +
-        labs(
-          title = stringr::str_wrap(title, wrap_title),
-          subtitle = stringr::str_wrap(subtitle, wrap_subtitle),
-          x = stringr::str_wrap(x_title, wrap_x_title),
-          y = stringr::str_wrap(y_title, wrap_y_title),
-          caption = stringr::str_wrap(caption, wrap_caption)
-        ) +
-        facet_wrap(vars(!!facet_var), scales = facet_scales, nrow = facet_nrow)
-    }
-    else if (isMobile == TRUE){
-      plot <- plot +
-        labs(
-          title = stringr::str_wrap(title, 40),
-          subtitle = stringr::str_wrap(subtitle, 40),
-          x = stringr::str_wrap(x_title, 20),
-          y = stringr::str_wrap(y_title, 30),
-          caption = stringr::str_wrap(caption, 50)
-        ) +
-        facet_wrap(vars(!!facet_var), scales = facet_scales, ncol = 1) +
-        coord_flip() +
-        theme(panel.grid.major.x = element_line(colour = "#D3D3D3", size = 0.2)) +
-        theme(panel.grid.major.y = element_blank())
-    }
+    if (is.null(facet_nrow) & length(unique(facet_var_vctr)) <= 3) facet_nrow <- 1
+    if (is.null(facet_nrow) & length(unique(facet_var_vctr)) > 3) facet_nrow <- 2
     
+    plot <- plot +
+      labs(
+        title = stringr::str_wrap(title, title_wrap),
+        subtitle = stringr::str_wrap(subtitle, subtitle_wrap),
+        x = stringr::str_wrap(x_title, x_title_wrap),
+        y = stringr::str_wrap(y_title, y_title_wrap),
+        caption = stringr::str_wrap(caption, caption_wrap)
+      ) +
+      facet_wrap(vars(!!facet_var), scales = facet_scales, nrow = facet_nrow)
+
     return(plot)
   }
