@@ -2,7 +2,7 @@
 
 #' @title Map of an array in leaflet.
 #' @description Map of an array in leaflet. 
-#' @param data A stars object with dimensions x and y with crs in wgs84 (epsg4326). Required input.
+#' @param data A stars object with dimensions x and y with crs. Required input.
 #' @param pal Character vector of hex codes, or provided objects with pal_ prefixes.
 #' @param opacity Sets the opacity of the grid cells. Defaults to 0.1.
 #' @param title A title string that will be wrapped into the legend. Defaults to "Title".
@@ -13,7 +13,7 @@
 #' @return A leaflet object.
 #' @export
 #' @examples
-#' leaflet_stars(example_stars_nz_no3n)
+#' leaflet_stars(example_stars)
 leaflet_stars <- function(data,
                           pal = NULL,
                           opacity = 0.5,
@@ -31,8 +31,8 @@ leaflet_stars <- function(data,
   data <- methods::as(data, "Raster")
   data <- projectRasterForLeaflet(data, method = "ngb")
   
-  if (is.null(pal))
-    pal <- pal_snz[1]
+  if (is.null(pal)) pal <- pal_snz[1]
+  
   pal_fun <-
     colorBin(
       palette = pal,
@@ -93,7 +93,7 @@ leaflet_stars <- function(data,
 
 #' @title Map of an array in leaflet that is coloured.
 #' @description Map of an array in leaflet that is coloured. 
-#' @param data A stars object with dimensions x and y, and 1 attribute layer with crs in wgs84 (epsg4326). Required input.
+#' @param data A stars object with dimensions x and y, and 1 attribute layer with crs. Required input.
 #' @param col_method The method of colouring features, either "bin", "quantile" or "category." Defaults to "quantile". Note all numeric variables are cut to be inclusive of the min in the range, and exclusive of the max in the range (except for the final bucket which includes the highest value).
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles. 
 #' @param pal Character vector of hex codes, or provided objects with pal_ prefixes. Defaults to viridis.
@@ -107,7 +107,7 @@ leaflet_stars <- function(data,
 #' @return A leaflet object.
 #' @export
 #' @examples
-#' leaflet_stars_col(example_stars_nz_no3n, 
+#' leaflet_stars_col(example_stars, 
 #'    col_method = "quantile", col_cuts = c(0, 0.05, 0.25, 0.5, 0.75, 0.95, 1),
 #'    title = "River modelled median nitrate-nitrogen concentrations in g/m\u00b3, 2013\u201317")
 leaflet_stars_col <- function(data,
@@ -129,13 +129,13 @@ leaflet_stars_col <- function(data,
   
   # data <- data %>% dplyr::select(1)
   
-  col_var_vector <- data %>% dplyr::pull()
+  col_var_vctr <- data %>% dplyr::pull()
   
   if (col_method == "category") {
     no_bins <-
-      max(col_var_vector, na.rm = TRUE) - min(col_var_vector, na.rm = TRUE) + 1
-    max_bin_cut <- max(col_var_vector, na.rm = TRUE) + 1
-    col_cuts <- seq(min(col_var_vector, na.rm = TRUE), max_bin_cut, 1)
+      max(col_var_vctr, na.rm = TRUE) - min(col_var_vctr, na.rm = TRUE) + 1
+    max_bin_cut <- max(col_var_vctr, na.rm = TRUE) + 1
+    col_cuts <- seq(min(col_var_vctr, na.rm = TRUE), max_bin_cut, 1)
     if (is.null(pal))
       pal <- pal_point_set1[1:(length(col_cuts) - 1)]
     else if (!is.null(pal))
@@ -145,7 +145,7 @@ leaflet_stars_col <- function(data,
     pal_fun <-
       colorBin(
         palette = pal,
-        domain = col_var_vector,
+        domain = col_var_vctr,
         bins = col_cuts,
         right = FALSE,
         na.color = "transparent"
@@ -157,7 +157,7 @@ leaflet_stars_col <- function(data,
       labels <- legend_labels
   }
   else if (col_method == "bin") {
-    if (is.null(col_cuts)) col_cuts <- pretty(col_var_vector)
+    if (is.null(col_cuts)) col_cuts <- pretty(col_var_vctr)
     else if (!is.null(col_cuts)) {
       if (!(dplyr::first(col_cuts) %in% c(0, -Inf))) warning("The first element of the col_cuts vector should generally be 0 (or -Inf if there are negative values)")
       if (dplyr::last(col_cuts) != Inf) warning("The last element of the col_cuts vector should generally be Inf")
@@ -171,7 +171,7 @@ leaflet_stars_col <- function(data,
     pal_fun <-
       colorBin(
         palette = pal,
-        domain = col_var_vector,
+        domain = col_var_vctr,
         pretty = FALSE,
         bins = col_cuts,
         right = FALSE,
@@ -193,12 +193,12 @@ leaflet_stars_col <- function(data,
     if (is.null(pal)) pal <- viridis::viridis(length(col_cuts) - 1)
     else if (!is.null(pal)) pal <- pal[1:(length(col_cuts) - 1)]
     if (pal_rev == TRUE) pal <- rev(pal)
-    col_cuts <- stats::quantile(col_var_vector, probs = col_cuts, na.rm = TRUE)
+    col_cuts <- stats::quantile(col_var_vctr, probs = col_cuts, na.rm = TRUE)
     
     pal_fun <-
       colorBin(
         palette = pal,
-        domain = col_var_vector,
+        domain = col_var_vctr,
         bins = col_cuts,
         right = FALSE,
         na.color = "transparent"
